    using System;
	using System.Collections.Generic;
	using System.IO;
	using System.Linq;
	using System.Net;
	using System.Security.Cryptography;
	using System.Text;
	using System.Web.Mvc;
	using Newtonsoft.Json;
	using Newtonsoft.Json.Linq;

	namespace Samples.Controllers
	{
	    public class SamplesController : Controller
	    {
	        [HttpGet]
	        public ActionResult Index()
	        {
	            return View();
	        }

	        [HttpPost]
	        public ActionResult Index(string paymentType, string money, string title)
	        {
	            var json = new JObject();

	            try
	            {
	                var dic = new Dictionary<string, string>
	                {
	                    {"version", "1.1"},
	                    {"lang", "zh-cn"},
	                    {"plugins", "test-001"},
	                    {"appid", "2147483647"},//appid
	                    {"appsecret", "160130736b1ac0d54ed7abe51e44840b"},//appsecret
	                    {"trade_order_id", Generate.GenerateOutTradeNo()},//订单号
	                    {"payment", "wechat"},//支付类型
	                    {"total_fee", money},//金额
	                    {"title", HttpUtility.UrlEncode("iphone")},//标题，中文需要编码“HttpUtility.UrlEncode()”
	                    {"time", Date.GetTimeStamp()},//时间戳
	                    {"notify_url", "https://www.baidu.com/"},//通知链接
	                    {"return_url", "https://www.baidu.com/"},//跳转链接
	                    {"nonce_str", Generate.RndNum(32)},//随机字符串
	                };

	                dic.Add("hash", Sign(dic));

	                var sr = JsonConvert.DeserializeObject<SamplesResult>(PostHttp(dic));

	                json.Add(new JProperty("openid", sr.Openid));
	                json.Add(new JProperty("url", sr.Url));
	                json.Add(new JProperty("errcode", sr.Errcode));
	                json.Add(new JProperty("errmsg", sr.Errmsg));
	                json.Add(new JProperty("hash", sr.Hash));
	            }
	            catch (Exception e)
	            {
	                throw e;
	            }

	            return Content(json.ToString());
	        }

	        public class SamplesResult
	        {
	            public string Openid { get; set; }

	            public string Url { get; set; }

	            public string Errcode { get; set; }

	            public string Errmsg { get; set; }

	            public string Hash { get; set; }
	        }

	        [HttpPost]
	        public ActionResult NotifyUrl()
	        {
	            var tradeOrderId = Request["trade_order_id"];
	            var totalFee = Request["total_fee"];
	            var transactionId = Request["transaction_id"];
	            var plugins = Request["plugins"];
	            var status = Request["status"];
	            var hash = Request["hash"];

	            return Content(!string.IsNullOrEmpty(tradeOrderId) ? "success" : "");
	        }

	        public static string PostHttp(Dictionary<string, string> dicArray)
	        {
	            string result;

	            try
	            {
	                var req = (HttpWebRequest)WebRequest.Create("https://api.xunhupay.com/payment/do.html");
	                req.KeepAlive = false;
	                req.Method = "POST";
	                req.ContentType = "application/x-www-form-urlencoded";
	                req.Accept = "application/json";

	                var paramData = ParamData(dicArray);
	                var data = Encoding.Default.GetBytes(paramData);

	                req.ContentLength = data.Length;

	                var swrite = req.GetRequestStream();
	                swrite.Write(data, 0, data.Length);
	                swrite.Close();

	                var resp = (HttpWebResponse)req.GetResponse();
	                var stream = resp.GetResponseStream();

	                //获取响应内容
	                var reader = new StreamReader(stream ?? throw new InvalidOperationException(), Encoding.UTF8);
	                result = reader.ReadToEnd();
	            }
	            catch (WebException ex)
	            {
	                result = ex.Message;
	            }

	            return result;
	        }

	        public static string Sign(Dictionary<string, string> dicArray)
	        {
	            var prestr = new StringBuilder();
	            foreach (var temp in dicArray.OrderBy(o => o.Key))
	            {
	                prestr.Append(temp.Key + "=" + temp.Value + "&");
	            }
	            var nLen = prestr.Length;
	            prestr.Remove(nLen - 1, 1);
	            var signValue = Md5Encoder(prestr + "你的AppSecret", 32);
	            return signValue;
	        }

	        public static string ParamData(Dictionary<string, string> dicArray)
	        {
	            var prestr = new StringBuilder();
	            foreach (var temp in dicArray)
	            {
	                prestr.Append(temp.Key + "=" + temp.Value + "&");
	            }

	            var nLen = prestr.Length;
	            prestr.Remove(nLen - 1, 1);

	            return prestr.ToString();
	        }

	        public static string Md5Encoder(string str, int bit)
	        {
	            var md5Hasher = new MD5CryptoServiceProvider();
	            var hashedDataBytes = md5Hasher.ComputeHash(Encoding.GetEncoding("gb2312").GetBytes(str));
	            var tmp = new StringBuilder();
	            foreach (var i in hashedDataBytes)
	            {
	                tmp.Append(i.ToString("x2"));
	            }

	            switch (bit)
	            {
	                case 16:
	                    return tmp.ToString().Substring(8, 16);
	                case 32:
	                    return tmp.ToString();//默认情况
	            }

	            return string.Empty;
	        }
	    }
	}
